==> RSTouchscreenNG-1.3.0.zip: RSTouchscreenNG/projects/front-ui/src/lib/modals/rsModal.component.ts <==
import {Compiler, ComponentFactoryResolver, ComponentRef, Injectable, ViewContainerRef} from "@angular/core";
import {Deferred, RSUtils} from "binding";
import {RSModalViewComponent} from "./modal-view.component";
import {RSConfirmModalComponent} from "./rsConfirmModal.component";
import {RSMessageModalComponent} from "./rsMessageModal.component";

@Injectable()
export class RSModal {
  static defaultView: ViewContainerRef = undefined;

  // private component: ComponentRef<{}> = undefined; // last created component

  constructor(public compiler: Compiler, public resolver: ComponentFactoryResolver) {
  }

  show(compType: any, data?: any, modalType?: any): Promise<any> {
    const deferred: Deferred = new Deferred();
    if (!data) {
      data = {};
    }
    if (typeof (data.closeable) === "undefined") {
      data.closeable = true;
    }
    if (!modalType) {
      modalType = RSModalViewComponent;
    }
    const factory = this.resolver.resolveComponentFactory(modalType);
    // this.compiler.compileComponentAsync(modalType).then((factory) => {
    // this.compiler.compileModuleAndAllComponentsAsync(modalType).then(a => {
    // RSModal.defaultView.clear(); // would delete also other existing modals!
    const component: ComponentRef<{}> = RSModal.defaultView.createComponent(factory, 0, RSModal.defaultView.injector);
    (deferred.promise as any).component = component as any;
    // var component: ComponentRef<{}> = component = RSModal.defaultView.createComponent(a.componentFactories[0]); //, 0, RSModal.defaultView.injector);
    (<RSModalViewComponent>component.instance).component = component;
    (<RSModalViewComponent>component.instance).deferred = deferred;
    (<RSModalViewComponent>component.instance).data = data;
    // (<RSModalView>component.instance).componentModule = compModule;
    (<RSModalViewComponent>component.instance).componentType = compType;
    (<RSModalViewComponent>component.instance).starter = this;
    if (data.modalClass) {
      (<RSModalViewComponent>component.instance).modalClass = data.modalClass;
    }
    if (data.componentCreatedCallback) {
      data.componentCreatedCallback(component);
    }
    // })
    return deferred.promise;
  }

  hide(prom: any) {
    const com: RSModalViewComponent = prom.component.instance as RSModalViewComponent;
    com.cancelIfAllowed();
  }

  confirm(head: string, question: string, options?: any): Promise<any> {
    if (!options) {
      options = {};
    }
    return this.show(RSConfirmModalComponent, RSUtils.extend({head: head, question: question}, options));
  }

  message(head: string, message: string, options?: any): Promise<any> {
    if (!options) {
      options = {};
    }
    return this.show(RSMessageModalComponent, RSUtils.extend({head: head, message: message}, options));
  }
  //
  // serverDialog(dialog: ServerDialog): Promise<any> {
  //   const data: any = {dialog: dialog};
  //   switch (dialog.dialogType) {
  //     case 1: // info
  //       data.modalClass = "modal-info";
  //       break;
  //     case 2: // warning
  //       data.modalClass = "modal-warning";
  //       break;
  //     case 3: // error
  //       data.modalClass = "modal-error";
  //       break;
  //     default:
  //       break;
  //   }
  //   const x = this.show(RSServerDialogModalComponent, data, RSModalViewDialogComponent);
  //   x.then(() => {
  //   }, () => {
  //   });
  //   return x;
  // }
}

==> RSTouchscreenNG-1.4.16.zip: RSTouchscreenNG/projects/front-ui/src/lib/modals/rsModal.component.ts <==
import {ComponentRef, Injectable, ViewContainerRef} from "@angular/core";
import {Deferred, RSUtils} from "binding";
import {RSModalViewComponent} from "./modal-view.component";
import {RSConfirmModalComponent} from "./rsConfirmModal.component";
import {RSMessageModalComponent} from "./rsMessageModal.component";

@Injectable()
export class RSModal {
  static defaultView: ViewContainerRef = undefined;

  // private component: ComponentRef<{}> = undefined; // last created component

  constructor() {
  }

  show(compType: any, data?: any, modalType?: any): Promise<any> {
    const deferred: Deferred = new Deferred();
    if (!data) {
      data = {};
    }
    if (typeof (data.closeable) === "undefined") {
      data.closeable = true;
    }
    if (!modalType) {
      modalType = RSModalViewComponent;
    }
    const component: ComponentRef<{}> = RSModal.defaultView.createComponent(modalType, {index: 0, injector: RSModal.defaultView.injector});
    (deferred.promise as any).component = component as any;
    // var component: ComponentRef<{}> = component = RSModal.defaultView.createComponent(a.componentFactories[0]); //, 0, RSModal.defaultView.injector);
    (<RSModalViewComponent>component.instance).component = component;
    (<RSModalViewComponent>component.instance).deferred = deferred;
    (<RSModalViewComponent>component.instance).data = data;
    // (<RSModalView>component.instance).componentModule = compModule;
    (<RSModalViewComponent>component.instance).componentType = compType;
    (<RSModalViewComponent>component.instance).starter = this;
    if (data.modalClass) {
      (<RSModalViewComponent>component.instance).modalClass = data.modalClass;
    }
    if (data.componentCreatedCallback) {
      data.componentCreatedCallback(component);
    }
    // })
    return deferred.promise;
  }

  hide(prom: any) {
    const com: RSModalViewComponent = prom.component.instance as RSModalViewComponent;
    com.cancelIfAllowed();
  }

  confirm(head: string, question: string, options?: any): Promise<any> {
    if (!options) {
      options = {};
    }
    return this.show(RSConfirmModalComponent, RSUtils.extend({head: head, question: question}, options));
  }

  message(head: string, message: string, options?: any): Promise<any> {
    if (!options) {
      options = {};
    }
    return this.show(RSMessageModalComponent, RSUtils.extend({head: head, message: message}, options));
  }
  //
  // serverDialog(dialog: ServerDialog): Promise<any> {
  //   const data: any = {dialog: dialog};
  //   switch (dialog.dialogType) {
  //     case 1: // info
  //       data.modalClass = "modal-info";
  //       break;
  //     case 2: // warning
  //       data.modalClass = "modal-warning";
  //       break;
  //     case 3: // error
  //       data.modalClass = "modal-error";
  //       break;
  //     default:
  //       break;
  //   }
  //   const x = this.show(RSServerDialogModalComponent, data, RSModalViewDialogComponent);
  //   x.then(() => {
  //   }, () => {
  //   });
  //   return x;
  // }
}
